@@ -753,7 +753,7 @@ sub invert_types {
     my $config = shift;
     return unless $config;
 
-    my $keys         = md5_hex(keys %$config);
+    my $keys         = md5_hex(sort keys %$config);
 
     # check in-memory cache
     if (exists $self->{_inverted}{$keys}) {
@@ -952,7 +952,7 @@ sub db_settings {
 
   # Do environment substitutions in the args. Assume that the environment is safe.
   foreach (@argv) {
-      s/\$ENV{(\w+)}/$ENV{$1}||''/ge;
+      s/\$ENV\{(\w+)\}/$ENV{$1}||''/ge;
       s/\$HTDOCS/Bio::Graphics::Browser2->htdocs_base/ge;
       s/\$DB/Bio::Graphics::Browser2->db_base/ge;
       s/\$CONF/Bio::Graphics::Browser2->config_base/ge;
