@@ -2227,7 +2227,7 @@ sub track_citation {
     my $id       = $self->tr('TRACK_ID',$label);
     my $download = a({-href=>"?l=$label;f=save+datafile"},$self->tr('DOWNLOAD_TRACK_DATA_ALL'));
     my $title    = div({-style => 'background:gainsboro;padding:5px;font-weight:bold'},$key,br(),$id,br(),$download);
-    return  join '',div({-style=>'text-align:center;font-size:small'},$title,$cit_html);
+    return  join '',div({-style=>'text-align:left;font-size:small'},$title,$cit_html);
 }
 
 sub download_track_menu {
@@ -2551,6 +2551,7 @@ sub can_generate_pdf {
     return $CAN_PDF = $source->global_setting('generate pdf') 
 	if defined $source->global_setting('generate pdf');
 
+    return $CAN_PDF=1 if `which svg2pdf`;
     return $CAN_PDF=0 unless `which inkscape`;
     # see whether we have the needed .inkscape and .gnome2 directories
     my $home = (getpwuid($<))[7];
@@ -2604,7 +2605,7 @@ sub display_citation {
         $key .= " (at >$lim bp)";
    }
 
-   my $citation = div({-class => 'searchbody', -style => 'padding:10px;width:70%'}, h4($key), $cit_txt);
+   my $citation = div({-class => 'searchbody', -style => 'padding:10px;width:70%'}, h4(escape($key)), $cit_txt);
      
  
    $return_html
